@@ -66,7 +66,7 @@ export const namespacedTemplateSchema: JSONSchema7 = {
   required: ['namespace', 'templateName'],
 };
 
-export const namespacedWorkspacePreferencesSchema: JSONSchema7 = {
+export const namespacedWorkspacePreferencesAuthorizationSchema: JSONSchema7 = {
   type: 'object',
   properties: {
     namespace: {
@@ -79,6 +79,16 @@ export const namespacedWorkspacePreferencesSchema: JSONSchema7 = {
   required: ['namespace', 'provider'],
 };
 
+export const namespacedWorkspacePreferencesTrustedSourceSchema: JSONSchema7 = {
+  type: 'object',
+  properties: {
+    source: {
+      type: 'string',
+    },
+  },
+  required: ['source'],
+};
+
 export const namespacedSchema: JSONSchema7 = {
   type: 'object',
   properties: {
@@ -150,19 +160,6 @@ export const gitConfigSchema: JSONSchema7 = {
   properties: {
     gitconfig: {
       type: 'object',
-      properties: {
-        user: {
-          type: 'object',
-          properties: {
-            name: {
-              type: 'string',
-            },
-            email: {
-              type: 'string',
-            },
-          },
-        },
-      },
     },
     resourceVersion: {
       type: 'string',
