@@ -14,6 +14,7 @@ import * as k8s from '@kubernetes/client-node';
 
 import { AirGapSampleApiService } from '@/devworkspaceClient/services/airGapSampleApi';
 import { DevWorkspaceApiService } from '@/devworkspaceClient/services/devWorkspaceApi';
+import { DevWorkspaceClusterApiService } from '@/devworkspaceClient/services/devWorkspaceClusterApiService';
 import { DevWorkspaceTemplateApiService } from '@/devworkspaceClient/services/devWorkspaceTemplateApi';
 import { DockerConfigApiService } from '@/devworkspaceClient/services/dockerConfigApi';
 import { EditorsApiService } from '@/devworkspaceClient/services/editorsApi';
@@ -33,6 +34,8 @@ import {
   IAirGapSampleApi,
   IDevWorkspaceApi,
   IDevWorkspaceClient,
+  IDevWorkspaceClusterApi,
+  IDevWorkspaceSingletonClient,
   IDevWorkspaceTemplateApi,
   IDockerConfigApi,
   IEditorsApi,
@@ -127,3 +130,22 @@ export class DevWorkspaceClient implements IDevWorkspaceClient {
     return new WorkspacePreferencesApiService(this.kubeConfig);
   }
 }
+
+let devWorkspaceSingletonClient: DevWorkspaceSingletonClient;
+
+/**
+ * Singleton client for devworkspace services.
+ */
+export class DevWorkspaceSingletonClient implements IDevWorkspaceSingletonClient {
+  static getInstance(kc: k8s.KubeConfig): DevWorkspaceSingletonClient {
+    if (!devWorkspaceSingletonClient) {
+      devWorkspaceSingletonClient = new DevWorkspaceSingletonClient(kc);
+    }
+    return devWorkspaceSingletonClient;
+  }
+
+  public readonly devWorkspaceClusterServiceApi: IDevWorkspaceClusterApi;
+  private constructor(kc: k8s.KubeConfig) {
+    this.devWorkspaceClusterServiceApi = new DevWorkspaceClusterApiService(kc);
+  }
+}
