@@ -113,6 +113,11 @@ describe('Server Config API Service', () => {
     expect(res).toEqual(1);
   });
 
+  test('getting running workspaces cluster limit', () => {
+    const res = serverConfigService.getRunningWorkspacesClusterLimit(buildCustomResource());
+    expect(res).toEqual(100);
+  });
+
   test('getting workspace inactivity timeout', () => {
     const res = serverConfigService.getWorkspaceInactivityTimeout(buildCustomResource());
     expect(res).toEqual(1800);
@@ -155,6 +160,11 @@ describe('Server Config API Service', () => {
     const res = serverConfigService.getAdvancedAuthorization(buildCustomResource());
     expect(res).toEqual({ allowUsers: ['user1', 'user2'] });
   });
+
+  test('getting allowed source urls', () => {
+    const res = serverConfigService.getAllowedSourceUrls(buildCustomResource());
+    expect(res).toEqual(['https://github.com']);
+  });
 });
 
 function buildCustomResourceList(): { body: CustomResourceDefinitionList } {
@@ -212,7 +222,11 @@ function buildCustomResource(options?: { openVSXURL?: string }): CheClusterCusto
         defaultEditor: 'eclipse/che-theia/latest',
         secondsOfInactivityBeforeIdling: 1800,
         secondsOfRunBeforeIdling: -1,
+        maxNumberOfRunningWorkspacesPerCluster: 100,
         storage: { pvcStrategy: 'per-user' },
+        allowedSources: {
+          urls: ['https://github.com'],
+        },
       },
       networking: {
         auth: {
