@@ -192,6 +192,11 @@ export class ServerConfigApiService implements IServerConfigApi {
     );
   }
 
+  getRunningWorkspacesClusterLimit(cheCustomResource: CheClusterCustomResource): number {
+    const limit = cheCustomResource.spec.devEnvironments?.maxNumberOfRunningWorkspacesPerCluster;
+    return limit === undefined ? -1 : limit;
+  }
+
   getAllWorkspacesLimit(cheCustomResource: CheClusterCustomResource): number {
     return cheCustomResource.spec.devEnvironments?.maxNumberOfWorkspacesPerUser || -1;
   }
@@ -223,4 +228,8 @@ export class ServerConfigApiService implements IServerConfigApi {
   getAutoProvision(cheCustomResource: CheClusterCustomResource): boolean {
     return cheCustomResource.spec.devEnvironments?.defaultNamespace?.autoProvision || false;
   }
+
+  getAllowedSourceUrls(cheCustomResource: CheClusterCustomResource): string[] {
+    return cheCustomResource.spec.devEnvironments?.allowedSources?.urls || [];
+  }
 }
