@@ -23,7 +23,9 @@ import { IncomingHttpHeaders } from 'http';
 
 import {
   DevWorkspaceClient,
+  DevWorkspaceSingletonClient,
   IDevWorkspaceApi,
+  IDevWorkspaceClusterApi,
   IDevWorkspaceTemplateApi,
   IDockerConfigApi,
   IEditorsApi,
@@ -154,11 +156,15 @@ export const stubAutoProvision = true;
 
 export const stubAdvancedAuthorization = {};
 
+export const stubAllowedSourceUrls: string[] = [];
+
 export const stubWorkspacePreferences: api.IWorkspacePreferences = {
   'skip-authorisation': ['github'],
   'trusted-sources': '*',
 };
 
+export const stubIsRunningWorkspaceClusterLimitExceeded = true;
+
 export const getDevWorkspaceClient = jest.fn(
   (..._args: Parameters<typeof helper>): ReturnType<typeof helper> => {
     return {
@@ -182,6 +188,7 @@ export const getDevWorkspaceClient = jest.fn(
         getDashboardLogo: _cheCustomResource => dashboardLogo,
         getAutoProvision: _cheCustomResource => stubAutoProvision,
         getAdvancedAuthorization: _cheCustomResource => stubAdvancedAuthorization,
+        getAllowedSourceUrls: _cheCustomResource => stubAllowedSourceUrls,
       } as IServerConfigApi,
       devworkspaceApi: {
         create: (_devworkspace, _namespace) =>
@@ -251,3 +258,17 @@ export const getDevWorkspaceClient = jest.fn(
     } as DevWorkspaceClient;
   },
 );
+
+export const getDevWorkspaceSingletonClient = jest.fn(
+  (..._args: Parameters<typeof helper>): DevWorkspaceSingletonClient => {
+    return {
+      devWorkspaceClusterServiceApi: {
+        isRunningWorkspacesClusterLimitExceeded: () =>
+          Promise.resolve(stubIsRunningWorkspaceClusterLimitExceeded),
+        watchInAllNamespaces(): Promise<void> {
+          return Promise.resolve();
+        },
+      } as IDevWorkspaceClusterApi,
+    };
+  },
+);
