@@ -10,8 +10,9 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import { DevWorkspaceClient } from '@/devworkspaceClient';
+import { DevWorkspaceClient, DevWorkspaceSingletonClient } from '@/devworkspaceClient';
 import { DwClientProvider } from '@/services/kubeclient/dwClientProvider';
+import { DwSingletonClientProvider } from '@/services/kubeclient/dwSingletonClientProvider';
 
 /**
  * Creates DevWorkspace Client depending on the context for the specified request.
@@ -20,3 +21,8 @@ export function getDevWorkspaceClient(token: string): DevWorkspaceClient {
   const dwClientProvider = new DwClientProvider();
   return dwClientProvider.getDWClient(token);
 }
+
+export function getDevWorkspaceSingletonClient(): DevWorkspaceSingletonClient {
+  const dwSingletonClientProvider = DwSingletonClientProvider.getInstance();
+  return dwSingletonClientProvider.getDWSingletonClient();
+}
