@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -21,7 +21,7 @@ export function registerWorkspaceRedirect(instance: FastifyInstance): void {
         const params = searchParams.get('params');
         if (params) {
           const parse: { namespace: string; workspace: string } = JSON.parse(params);
-          return reply.redirect(`/dashboard/#/ide/${parse.namespace}/${parse.workspace}`);
+          reply.redirect(`/dashboard/#/ide/${parse.namespace}/${parse.workspace}`);
         }
       });
     });
