@@ -38,3 +38,9 @@ jest.mock('@/components/CheTooltip', () => {
     }),
   };
 });
+
+jest.mock('react-markdown', () => {
+  return jest.fn(props => {
+    return React.createElement('a', null, props.children, props.content);
+  });
+});
