@@ -14,6 +14,7 @@ import {
   Card,
   CardActions,
   CardBody,
+  CardFooter,
   CardHeader,
   Dropdown,
   DropdownItem,
@@ -22,6 +23,7 @@ import {
 } from '@patternfly/react-core';
 import { CheckIcon } from '@patternfly/react-icons';
 import React from 'react';
+import ReactMarkdown from 'react-markdown';
 
 import styles from '@/components/EditorSelector/Gallery/Entry/index.module.css';
 import { TagLabel } from '@/components/TagLabel';
@@ -41,7 +43,11 @@ export type State = {
   isSelectedGroup: boolean;
 };
 
+const allowedTags = ['Tech Preview', 'Deprecated'];
+
 export class EditorSelectorEntry extends React.PureComponent<Props, State> {
+  private timerId: number | undefined;
+
   constructor(props: Props) {
     super(props);
 
@@ -56,7 +62,38 @@ export class EditorSelectorEntry extends React.PureComponent<Props, State> {
     };
   }
 
+  // TODO temporary solution for making links open in a new browser tab (should be fixed with https://github.com/eclipse-che/che/issues/23219)
+  private setAttribute(
+    widgetId: string,
+    querySelector: string = 'a',
+    attributeName: string = 'target',
+    attributeValue: string = '_blank',
+  ): void {
+    clearTimeout(this.timerId);
+    this.timerId = window.setTimeout(() => {
+      const widget = document.getElementById(widgetId);
+      if (widget) {
+        widget.querySelectorAll(querySelector).forEach(targetElement => {
+          targetElement.setAttribute(attributeName, attributeValue);
+        });
+      }
+    }, 500);
+  }
+
+  private get id(): string {
+    return `editor-selector-card-${this.state.activeEditor.id}`;
+  }
+
+  public componentDidMount(): void {
+    if (this.state.activeEditor.provider) {
+      this.setAttribute(this.id);
+    }
+  }
+
   public componentDidUpdate(prevProps: Props): void {
+    if (this.state.activeEditor.provider) {
+      this.setAttribute(this.id);
+    }
     if (prevProps.selectedId !== this.props.selectedId) {
       const selectedEditor = this.props.editorsGroup.find(
         editor => editor.id === this.props.selectedId,
@@ -77,11 +114,13 @@ export class EditorSelectorEntry extends React.PureComponent<Props, State> {
   }
 
   private handleCardClick(event: React.MouseEvent) {
-    event.preventDefault();
-
     const { selectedId, onSelect } = this.props;
     const { activeEditor } = this.state;
 
+    if (!activeEditor.provider) {
+      event.preventDefault();
+    }
+
     if (activeEditor.id === selectedId) {
       return;
     }
@@ -150,14 +189,18 @@ export class EditorSelectorEntry extends React.PureComponent<Props, State> {
       groupIconMediatype === 'image/svg+xml'
         ? `data:image/svg+xml;charset=utf-8,${encodeURIComponent(groupIcon)}`
         : groupIcon;
-    const hasTechPreviewTag =
-      (activeEditor.tags || []).includes('tech-preview') === true ||
-      /idea/i.test(activeEditor.id) === true;
+
+    const tags = (activeEditor.tags || [])
+      .map(tag => {
+        const words = tag.trim().toLowerCase().replace(/-/g, ' ').split(' ');
+        return words.map(word => word.charAt(0).toUpperCase() + word.slice(1)).join(' ');
+      })
+      .filter(tag => allowedTags.includes(tag));
     const tagsGroup = (
       <LabelGroup isVertical>
         <TagLabel type="version" text={activeEditor.version} />
-        {hasTechPreviewTag ? (
-          <TagLabel type="tag" text="Tech Preview" />
+        {tags.length > 0 ? (
+          tags.map(tag => <TagLabel key={tag} type="tag" text={tag} />)
         ) : (
           <span style={{ padding: '0 5px', lineHeight: '12px', visibility: 'hidden' }}>&nbsp;</span>
         )}
@@ -167,7 +210,7 @@ export class EditorSelectorEntry extends React.PureComponent<Props, State> {
     return (
       <Card
         hasSelectableInput={true}
-        id={'editor-selector-card-' + activeEditor.id}
+        id={this.id}
         isCompact={true}
         isFlat={true}
         isSelectableRaised
@@ -194,6 +237,11 @@ export class EditorSelectorEntry extends React.PureComponent<Props, State> {
         <CardBody>
           <span className={titleClassName}>{groupName}</span>
         </CardBody>
+        {activeEditor.provider && (
+          <CardFooter>
+            <ReactMarkdown className={styles.provider}>{activeEditor.provider}</ReactMarkdown>
+          </CardFooter>
+        )}
       </Card>
     );
   }
