@@ -12,7 +12,7 @@
 
 import { StateMock } from '@react-mock/state';
 import { waitFor } from '@testing-library/react';
-import userEvent from '@testing-library/user-event';
+import userEvent, { UserEvent } from '@testing-library/user-event';
 import { createMemoryHistory } from 'history';
 import React from 'react';
 import { Provider } from 'react-redux';
@@ -28,6 +28,7 @@ import { constructWorkspace } from '@/services/workspace-adapter';
 import { AppThunk } from '@/store';
 import { DevWorkspaceBuilder } from '@/store/__mocks__/devWorkspaceBuilder';
 import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
+import { ActionCreators as DevWorkspaceClusterActionCreators } from '@/store/DevWorkspacesCluster';
 import { ActionCreators } from '@/store/Workspaces';
 
 import CommonStepCheckRunningWorkspacesLimit, { State } from '..';
@@ -36,6 +37,8 @@ jest.mock('@/components/WorkspaceProgress/TimeLimit');
 
 const mockStartWorkspace = jest.fn();
 const mockStopWorkspace = jest.fn();
+const mockRequestRunningDevWorkspacesClusterLimitExceeded = jest.fn();
+
 jest.mock('@/store/Workspaces/index', () => {
   return {
     actionCreators: {
@@ -53,6 +56,19 @@ jest.mock('@/store/Workspaces/index', () => {
   };
 });
 
+jest.mock('@/store/DevWorkspacesCluster', () => {
+  const requireActual = jest.requireActual('@/store/DevWorkspacesCluster');
+  return {
+    ...requireActual,
+    actionCreators: {
+      requestRunningDevWorkspacesClusterLimitExceeded:
+        (): AppThunk<Action, Promise<void>> => async (): Promise<void> => {
+          return mockRequestRunningDevWorkspacesClusterLimitExceeded();
+        },
+    } as DevWorkspaceClusterActionCreators,
+  };
+});
+
 const mockOnNextStep = jest.fn();
 const mockOnRestart = jest.fn();
 const mockOnError = jest.fn();
@@ -78,6 +94,7 @@ describe('Common steps, check running workspaces limit', () => {
   let runningDevworkspaceBuilder1: DevWorkspaceBuilder;
   let runningDevworkspaceBuilder2: DevWorkspaceBuilder;
   let stoppedDevworkspaceBuilder: DevWorkspaceBuilder;
+  let user: UserEvent;
 
   beforeEach(() => {
     runningDevworkspaceBuilder1 = new DevWorkspaceBuilder()
@@ -97,11 +114,14 @@ describe('Common steps, check running workspaces limit', () => {
       .withNamespace(namespace);
 
     jest.useFakeTimers();
+
+    user = userEvent.setup({ advanceTimers: jest.advanceTimersByTime });
   });
 
   afterEach(() => {
     jest.clearAllMocks();
     jest.clearAllTimers();
+    jest.runOnlyPendingTimers();
     jest.useRealTimers();
   });
 
@@ -117,7 +137,11 @@ describe('Common steps, check running workspaces limit', () => {
       })
       .build();
 
-    renderComponent(store);
+    renderComponent(store, {
+      shouldCheckLimits: false,
+      shouldStop: false,
+      name: 'Checking for the limit of running workspaces',
+    });
     await jest.runOnlyPendingTimersAsync();
 
     await waitFor(() => expect(mockOnNextStep).toHaveBeenCalled());
@@ -125,6 +149,73 @@ describe('Common steps, check running workspaces limit', () => {
     expect(mockOnRestart).not.toHaveBeenCalled();
   });
 
+  test('should check cluster limit of running workspaces', async () => {
+    const runningDevworkspace = runningDevworkspaceBuilder1.build();
+    const stoppedDevworkspace = stoppedDevworkspaceBuilder.build();
+    const store = new FakeStoreBuilder()
+      .withDevWorkspaces({
+        workspaces: [runningDevworkspace, stoppedDevworkspace],
+      })
+      .withDevWorkspacesCluster({
+        isRunningDevWorkspacesClusterLimitExceeded: false,
+      })
+      .build();
+
+    renderComponent(store, {
+      shouldCheckLimits: true,
+      shouldStop: false,
+      name: 'Checking for the limit of running workspaces',
+    });
+    await jest.runOnlyPendingTimersAsync();
+
+    expect(mockOnNextStep).not.toHaveBeenCalled();
+    expect(mockOnError).not.toHaveBeenCalled();
+    expect(mockOnRestart).not.toHaveBeenCalled();
+  });
+
+  test('should throw error if cluster limit of running workspaces exceeded', async () => {
+    const runningDevworkspace = runningDevworkspaceBuilder1.build();
+    const stoppedDevworkspace = stoppedDevworkspaceBuilder.build();
+    const store = new FakeStoreBuilder()
+      .withDevWorkspaces({
+        workspaces: [runningDevworkspace, stoppedDevworkspace],
+      })
+      .withDevWorkspacesCluster({
+        isRunningDevWorkspacesClusterLimitExceeded: true,
+      })
+      .build();
+
+    renderComponent(store, {
+      shouldCheckLimits: false,
+      shouldStop: false,
+      name: 'Checking for the limit of running workspaces',
+    });
+
+    jest.runAllTimers();
+
+    // need to flush promises
+    await Promise.resolve();
+
+    const expectAlertItem = expect.objectContaining({
+      title: 'Running workspace(s) found.',
+      children: 'Exceeded the cluster limit for running DevWorkspaces',
+      actionCallbacks: [
+        expect.objectContaining({
+          title: 'Close running workspace (wksp-1) and restart',
+          callback: expect.any(Function),
+        }),
+        expect.objectContaining({
+          title: 'Switch to running workspace (wksp-1) to save any changes',
+          callback: expect.any(Function),
+        }),
+      ],
+    });
+    await waitFor(() => expect(mockOnError).toHaveBeenCalledWith(expectAlertItem));
+
+    expect(mockOnNextStep).not.toHaveBeenCalled();
+    expect(mockOnRestart).not.toHaveBeenCalled();
+  });
+
   describe('start a workspace above the limit, limit equals 1', () => {
     let store: Store;
     let runningDevworkspace: devfileApi.DevWorkspace;
@@ -144,7 +235,11 @@ describe('Common steps, check running workspaces limit', () => {
     });
 
     test('alert notification', async () => {
-      renderComponent(store);
+      renderComponent(store, {
+        shouldCheckLimits: false,
+        shouldStop: false,
+        name: 'Checking for the limit of running workspaces',
+      });
       jest.runAllTimers();
 
       // need to flush promises
@@ -187,7 +282,11 @@ describe('Common steps, check running workspaces limit', () => {
         }
       });
 
-      renderComponent(store);
+      renderComponent(store, {
+        shouldCheckLimits: false,
+        shouldStop: false,
+        name: 'Checking for the limit of running workspaces',
+      });
       await jest.runAllTimersAsync();
 
       await waitFor(() => expect(mockOnError).toHaveBeenCalled());
@@ -220,7 +319,11 @@ describe('Common steps, check running workspaces limit', () => {
         }
       });
 
-      renderComponent(store);
+      renderComponent(store, {
+        shouldCheckLimits: false,
+        shouldStop: false,
+        name: 'Checking for the limit of running workspaces',
+      });
       await jest.runOnlyPendingTimersAsync();
 
       await waitFor(() => expect(mockOnError).toHaveBeenCalled());
@@ -254,6 +357,7 @@ describe('Common steps, check running workspaces limit', () => {
           .build();
         localState = {
           shouldStop: true,
+          shouldCheckLimits: false,
           redundantWorkspaceUID: constructWorkspace(redundantDevworkspace).uid,
         };
       });
@@ -263,7 +367,7 @@ describe('Common steps, check running workspaces limit', () => {
 
         // imitate the timeout has been expired
         const timeoutButton = screen.getByRole('button', { name: 'onTimeout' });
-        userEvent.click(timeoutButton);
+        await user.click(timeoutButton);
 
         const expectAlertItem = expect.objectContaining({
           title: 'Failed to open the workspace',
@@ -302,7 +406,7 @@ describe('Common steps, check running workspaces limit', () => {
 
         // imitate the timeout has been expired
         const timeoutButton = screen.getByRole('button', { name: 'onTimeout' });
-        userEvent.click(timeoutButton);
+        await user.click(timeoutButton);
 
         await waitFor(() => expect(mockOnError).toHaveBeenCalled());
         expect(mockOnNextStep).not.toHaveBeenCalled();
@@ -344,7 +448,12 @@ describe('Common steps, check running workspaces limit', () => {
             workspaces: [targetDevworkspace, nextRedundantDevworkspace, stoppedDevworkspace],
           })
           .build();
-        reRenderComponent(nextStore);
+        reRenderComponent(nextStore, {
+          shouldCheckLimits: false,
+          shouldStop: false,
+          redundantWorkspaceUID: nextRedundantDevworkspace.status?.devworkspaceId,
+          name: 'Checking for the limit of running workspaces',
+        });
         await jest.runOnlyPendingTimersAsync();
 
         // switch to the next step
@@ -355,6 +464,66 @@ describe('Common steps, check running workspaces limit', () => {
     });
   });
 
+  describe('start a workspace above the cluster limit, limit equals 2', () => {
+    let storeBuilder: FakeStoreBuilder;
+    let runningDevworkspace1: devfileApi.DevWorkspace;
+    let runningDevworkspace2: devfileApi.DevWorkspace;
+
+    beforeEach(() => {
+      runningDevworkspace1 = runningDevworkspaceBuilder1.build();
+      runningDevworkspace2 = runningDevworkspaceBuilder1.build();
+      storeBuilder = new FakeStoreBuilder()
+        .withDevWorkspaces({
+          workspaces: [targetDevworkspace, runningDevworkspace1, runningDevworkspace2],
+        })
+        .withClusterConfig({
+          runningWorkspacesLimit: 10,
+        });
+    });
+
+    test('alert notification', async () => {
+      const store = storeBuilder
+        .withDevWorkspacesCluster({ isRunningDevWorkspacesClusterLimitExceeded: true })
+        .build();
+      renderComponent(store, {
+        shouldCheckLimits: false,
+        shouldStop: false,
+        name: 'Checking for the limit of running workspaces',
+      });
+      await jest.runAllTimersAsync();
+
+      const expectAlertItem = expect.objectContaining({
+        title: 'Running workspace(s) found.',
+        children: 'Exceeded the cluster limit for running DevWorkspaces',
+        actionCallbacks: [
+          expect.objectContaining({
+            title: 'Return to dashboard',
+            callback: expect.any(Function),
+          }),
+        ],
+      });
+      await waitFor(() => expect(mockOnError).toHaveBeenCalledWith(expectAlertItem));
+      expect(mockOnNextStep).not.toHaveBeenCalled();
+      expect(mockOnRestart).not.toHaveBeenCalled();
+    });
+
+    test('start a workspace', async () => {
+      const store = storeBuilder
+        .withDevWorkspacesCluster({ isRunningDevWorkspacesClusterLimitExceeded: false })
+        .build();
+      renderComponent(store, {
+        shouldCheckLimits: false,
+        shouldStop: false,
+        name: 'Checking for the limit of running workspaces',
+      });
+      await jest.runAllTimersAsync();
+
+      expect(mockOnError).not.toHaveBeenCalled();
+      expect(mockOnNextStep).toHaveBeenCalled();
+      expect(mockOnRestart).not.toHaveBeenCalled();
+    });
+  });
+
   describe('start a workspace above the limit, limit equals 2', () => {
     let store: Store;
     let runningDevworkspace1: devfileApi.DevWorkspace;
@@ -381,7 +550,11 @@ describe('Common steps, check running workspaces limit', () => {
     });
 
     test('alert notification', async () => {
-      renderComponent(store);
+      renderComponent(store, {
+        shouldCheckLimits: false,
+        shouldStop: false,
+        name: 'Checking for the limit of running workspaces',
+      });
       await jest.runAllTimersAsync();
 
       const expectAlertItem = expect.objectContaining({
@@ -416,7 +589,11 @@ describe('Common steps, check running workspaces limit', () => {
         }
       });
 
-      renderComponent(store);
+      renderComponent(store, {
+        shouldCheckLimits: false,
+        shouldStop: false,
+        name: 'Checking for the limit of running workspaces',
+      });
       await jest.runOnlyPendingTimersAsync();
 
       await waitFor(() => expect(mockOnError).toHaveBeenCalled());
