@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -19,7 +19,7 @@ import { DEVWORKSPACE_DEVFILE_SOURCE } from '@/services/workspace-client/devwork
 import { DevWorkspaceResources } from '@/store/DevfileRegistries';
 
 const suffix = '-1234';
-jest.mock('../../../../../../services/helpers/generateName');
+jest.mock('@/services/helpers/generateName');
 (generateSuffix as jest.Mock).mockImplementation(() => suffix);
 
 describe('FactoryLoaderContainer/prepareResources', () => {
