@@ -13,8 +13,9 @@
 /* eslint-disable @typescript-eslint/no-non-null-assertion */
 
 import { FACTORY_LINK_ATTR } from '@eclipse-che/common';
+import { AlertVariant } from '@patternfly/react-core';
 import { cleanup, screen, waitFor } from '@testing-library/react';
-import userEvent from '@testing-library/user-event';
+import userEvent, { UserEvent } from '@testing-library/user-event';
 import { createMemoryHistory, MemoryHistory } from 'history';
 import React from 'react';
 import { Provider } from 'react-redux';
@@ -80,6 +81,7 @@ describe('Creating steps, fetching a devfile', () => {
   let searchParams: URLSearchParams;
   let store: Store;
   let devfile: devfileApi.Devfile;
+  let user: UserEvent;
 
   beforeEach(() => {
     devfile = {
@@ -104,26 +106,14 @@ describe('Creating steps, fetching a devfile', () => {
     });
 
     jest.useFakeTimers();
+
+    user = userEvent.setup({ advanceTimers: jest.advanceTimersByTime });
   });
 
   afterEach(() => {
     jest.clearAllMocks();
     jest.clearAllTimers();
-  });
-
-  test('factory should not resolve the SSH location', async () => {
-    const searchParams = new URLSearchParams({
-      [FACTORY_URL_ATTR]: 'git@github.com:eclipse-che/che-dashboard.git',
-    });
-
-    renderComponent(store, searchParams);
-
-    await jest.advanceTimersByTimeAsync(MIN_STEP_DURATION_MS);
-
-    await waitFor(() => expect(mockOnNextStep).toHaveBeenCalled());
-    expect(mockOnError).not.toHaveBeenCalled();
-    expect(mockOnRestart).not.toHaveBeenCalled();
-    expect(mockRequestFactoryResolver).not.toHaveBeenCalled();
+    jest.useRealTimers();
   });
 
   test('devfile is already resolved', async () => {
@@ -221,10 +211,10 @@ describe('Creating steps, fetching a devfile', () => {
       mockOnError.mockClear();
 
       /* test the action */
+      await jest.runOnlyPendingTimersAsync();
 
       // resolve deferred to trigger the callback
       deferred.resolve();
-      await jest.runOnlyPendingTimersAsync();
 
       await waitFor(() => expect(mockOnNextStep).toHaveBeenCalled());
       expect(mockOnRestart).not.toHaveBeenCalled();
@@ -262,10 +252,10 @@ describe('Creating steps, fetching a devfile', () => {
       mockOnError.mockClear();
 
       /* test the action */
+      await jest.runOnlyPendingTimersAsync();
 
       // resolve deferred to trigger the callback
       deferred.resolve();
-      await jest.runOnlyPendingTimersAsync();
 
       await waitFor(() => expect(mockOnRestart).toHaveBeenCalled());
       expect(mockOnNextStep).not.toHaveBeenCalled();
@@ -291,7 +281,7 @@ describe('Creating steps, fetching a devfile', () => {
       const timeoutButton = screen.getByRole('button', {
         name: 'onTimeout',
       });
-      userEvent.click(timeoutButton);
+      await user.click(timeoutButton);
 
       const expectAlertItem = expect.objectContaining({
         title: 'Failed to create the workspace',
@@ -338,7 +328,7 @@ describe('Creating steps, fetching a devfile', () => {
       const timeoutButton = screen.getByRole('button', {
         name: 'onTimeout',
       });
-      userEvent.click(timeoutButton);
+      await user.click(timeoutButton);
 
       await waitFor(() => expect(mockOnError).toHaveBeenCalled());
       mockOnError.mockClear();
@@ -417,10 +407,10 @@ describe('Creating steps, fetching a devfile', () => {
       mockOnError.mockClear();
 
       /* test the action */
+      await jest.runOnlyPendingTimersAsync();
 
       // resolve deferred to trigger the callback
       deferred.resolve();
-      await jest.runOnlyPendingTimersAsync();
 
       await waitFor(() => expect(mockOnNextStep).toHaveBeenCalled());
       expect(mockOnRestart).not.toHaveBeenCalled();
@@ -459,9 +449,10 @@ describe('Creating steps, fetching a devfile', () => {
 
       /* test the action */
 
+      await jest.runAllTimersAsync();
+
       // resolve deferred to trigger the callback
       deferred.resolve();
-      await jest.runOnlyPendingTimersAsync();
 
       await waitFor(() => expect(mockOnRestart).toHaveBeenCalled());
       expect(mockOnNextStep).not.toHaveBeenCalled();
@@ -719,6 +710,7 @@ describe('Creating steps, fetching a devfile', () => {
         [FACTORY_URL_ATTR]: factoryUrl,
       });
 
+      mockIsOAuthResponse.mockReturnValue(false);
       mockRequestFactoryResolver.mockRejectedValue('Could not reach devfile');
 
       spyWindowLocation = createWindowLocationSpy(host, protocol);
@@ -738,9 +730,21 @@ describe('Creating steps, fetching a devfile', () => {
     });
 
     it('should go to next step', async () => {
-      const emptyStore = new FakeStoreBuilder().build();
-
-      renderComponent(emptyStore, searchParams, history);
+      const nextStore = new FakeStoreBuilder()
+        .withFactoryResolver({
+          resolver: {
+            location: factoryUrl,
+            devfile: {
+              schemaVersion: '2.3.0',
+              metadata: {
+                name: 'my-project',
+                namespace: 'user-che',
+              },
+            },
+          },
+        })
+        .build();
+      renderComponent(nextStore, searchParams, history);
 
       await jest.advanceTimersByTimeAsync(MIN_STEP_DURATION_MS);
 
@@ -749,6 +753,46 @@ describe('Creating steps, fetching a devfile', () => {
       expect(mockOpenOAuthPage).not.toHaveBeenCalled();
       expect(mockOnError).not.toHaveBeenCalled();
     });
+
+    it('should show warning on SSH url', async () => {
+      const expectAlertItem = expect.objectContaining({
+        title: 'Warning',
+        variant: AlertVariant.warning,
+        children: (
+          <ExpandableWarning
+            textBefore="Devfile resolve from a privatre repositry via an SSH url is not supported."
+            errorMessage="Could not reach devfile"
+            textAfter="Apply a Personal Access Token to fetch the devfile.yaml content."
+          />
+        ),
+        actionCallbacks: [
+          expect.objectContaining({
+            title: 'Continue with default devfile',
+            callback: expect.any(Function),
+          }),
+          expect.objectContaining({
+            title: 'Reload',
+            callback: expect.any(Function),
+          }),
+          expect.objectContaining({
+            title: 'Open Documentation page',
+            callback: expect.any(Function),
+          }),
+        ],
+      });
+      searchParams = new URLSearchParams({
+        [FACTORY_URL_ATTR]: 'git@github.com:user/repository.git',
+      });
+      const emptyStore = new FakeStoreBuilder().build();
+      renderComponent(emptyStore, searchParams, history);
+
+      await jest.advanceTimersByTimeAsync(MIN_STEP_DURATION_MS);
+
+      await waitFor(() => expect(mockOnNextStep).not.toHaveBeenCalled);
+
+      expect(mockOpenOAuthPage).not.toHaveBeenCalled();
+      expect(mockOnError).toHaveBeenCalledWith(expectAlertItem);
+    });
   });
 });
 
