@@ -26,7 +26,6 @@ import {
 } from '@/components/WorkspaceProgress/ProgressStep';
 import { ProgressStepTitle } from '@/components/WorkspaceProgress/StepTitle';
 import { TimeLimit } from '@/components/WorkspaceProgress/TimeLimit';
-import { FactoryLocationAdapter } from '@/services/factory-location-adapter';
 import {
   buildFactoryParams,
   FactoryParams,
@@ -36,6 +35,7 @@ import { AlertItem } from '@/services/helpers/types';
 import { isOAuthResponse, OAuthService } from '@/services/oauth';
 import SessionStorageService, { SessionStorageKey } from '@/services/session-storage';
 import { AppState } from '@/store';
+import { selectBranding } from '@/store/Branding/selectors';
 import { factoryResolverActionCreators, selectFactoryResolver } from '@/store/FactoryResolver';
 import { selectAllWorkspaces } from '@/store/Workspaces/selectors';
 
@@ -53,6 +53,13 @@ export class UnsupportedGitProviderError extends Error {
   }
 }
 
+export class SSHPrivateRepositoryUrlError extends Error {
+  constructor(message: string) {
+    super(message);
+    this.name = 'UnsupportedGitProviderError';
+  }
+}
+
 const RELOADS_LIMIT = 2;
 type ReloadsInfo = {
   [url: string]: number;
@@ -75,9 +82,7 @@ class CreatingStepFetchDevfile extends ProgressStep<Props, State> {
     super(props);
 
     const factoryParams = buildFactoryParams(props.searchParams);
-    const name = FactoryLocationAdapter.isHttpLocation(factoryParams.sourceUrl)
-      ? `Inspecting repo ${factoryParams.sourceUrl} for a devfile`
-      : 'Applying default devfile';
+    const name = `Inspecting repo ${factoryParams.sourceUrl} for a devfile`;
 
     this.state = {
       factoryParams,
@@ -182,6 +187,10 @@ class CreatingStepFetchDevfile extends ProgressStep<Props, State> {
     this.clearStepError();
   }
 
+  protected handleOpenDocumentationPage(): void {
+    window.open(this.props.branding.docs.startWorkspaceFromGit, '_blank');
+  }
+
   protected handleTimeout(): void {
     const timeoutError = new Error(
       `Devfile hasn't been resolved in the last ${TIMEOUT_TO_RESOLVE_SEC} seconds.`,
@@ -209,12 +218,6 @@ class CreatingStepFetchDevfile extends ProgressStep<Props, State> {
       return true;
     }
 
-    // do not resolve a devfile if git+SSH URL is provided
-    if (FactoryLocationAdapter.isSshLocation(sourceUrl)) {
-      this.handleDefaultDevfile('');
-      return true;
-    }
-
     let resolveDone = false;
     try {
       // start resolving the devfile
@@ -229,7 +232,11 @@ class CreatingStepFetchDevfile extends ProgressStep<Props, State> {
         errorMessage === 'Failed to fetch devfile' ||
         errorMessage.startsWith('Could not reach devfile')
       ) {
-        throw new UnsupportedGitProviderError(errorMessage);
+        if (sourceUrl.startsWith('git@')) {
+          throw new SSHPrivateRepositoryUrlError(errorMessage);
+        } else {
+          throw new UnsupportedGitProviderError(errorMessage);
+        }
       }
       throw e;
     }
@@ -374,6 +381,34 @@ class CreatingStepFetchDevfile extends ProgressStep<Props, State> {
         ],
       };
     }
+    if (error instanceof SSHPrivateRepositoryUrlError) {
+      return {
+        key,
+        title: 'Warning',
+        variant: AlertVariant.warning,
+        children: (
+          <ExpandableWarning
+            textBefore="Devfile resolve from a privatre repositry via an SSH url is not supported."
+            errorMessage={helpers.errors.getMessage(error)}
+            textAfter="Apply a Personal Access Token to fetch the devfile.yaml content."
+          />
+        ),
+        actionCallbacks: [
+          {
+            title: 'Continue with default devfile',
+            callback: () => this.handleDefaultDevfile(key),
+          },
+          {
+            title: 'Reload',
+            callback: () => this.handleRestart(key),
+          },
+          {
+            title: 'Open Documentation page',
+            callback: () => this.handleOpenDocumentationPage(),
+          },
+        ],
+      };
+    }
     return {
       key,
       title: 'Failed to create the workspace',
@@ -426,6 +461,7 @@ class CreatingStepFetchDevfile extends ProgressStep<Props, State> {
 const mapStateToProps = (state: AppState) => ({
   allWorkspaces: selectAllWorkspaces(state),
   factoryResolver: selectFactoryResolver(state),
+  branding: selectBranding(state),
 });
 
 const connector = connect(mapStateToProps, factoryResolverActionCreators, null, {
