@@ -10,7 +10,7 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import { helpers } from '@eclipse-che/common';
+import { api, helpers } from '@eclipse-che/common';
 import { AlertVariant, pluralize } from '@patternfly/react-core';
 import isEqual from 'lodash/isEqual';
 import React from 'react';
@@ -36,8 +36,11 @@ import { AppState } from '@/store';
 import { selectAllWorkspacesLimit } from '@/store/ClusterConfig/selectors';
 import { selectIsRegistryDevfile } from '@/store/DevfileRegistries/selectors';
 import { selectInfrastructureNamespaces } from '@/store/InfrastructureNamespaces/selectors';
+import { isSourceAllowed } from '@/store/ServerConfig/helpers';
+import { selectAllowedSources } from '@/store/ServerConfig/selectors';
 import { selectSshKeys } from '@/store/SshKeys/selectors';
-import { selectPreferencesIsTrustedSource } from '@/store/Workspaces/Preferences';
+import { selectPreferencesTrustedSources } from '@/store/Workspaces/Preferences';
+import { isTrustedRepo } from '@/store/Workspaces/Preferences/helpers';
 import { selectAllWorkspaces } from '@/store/Workspaces/selectors';
 
 export type Props = MappedProps &
@@ -47,6 +50,8 @@ export type Props = MappedProps &
 export type State = ProgressStepState & {
   factoryParams: FactoryParams;
   isSourceTrusted: boolean;
+  allowedSources: string[];
+  isSourceAllowed: boolean;
   isWarning: boolean;
 };
 
@@ -61,6 +66,8 @@ class CreatingStepInitialize extends ProgressStep<Props, State> {
       isSourceTrusted: false,
       name: this.name,
       isWarning: false,
+      allowedSources: [],
+      isSourceAllowed: false,
     };
   }
 
@@ -96,8 +103,20 @@ class CreatingStepInitialize extends ProgressStep<Props, State> {
     }
 
     // source URL trusted/untrusted
-    const { sourceUrl } = nextState.factoryParams;
-    if (this.state.isSourceTrusted !== this.isSourceTrusted(sourceUrl)) {
+    const trustedSourcesStr = Array.isArray(this.props.trustedSources)
+      ? this.props.trustedSources.join(',')
+      : this.props.trustedSources;
+    const nextTrustedSourcesStr = Array.isArray(nextProps.trustedSources)
+      ? nextProps.trustedSources.join(',')
+      : nextProps.trustedSources;
+    if (trustedSourcesStr !== nextTrustedSourcesStr) {
+      return true;
+    }
+
+    if (
+      this.state.isSourceAllowed !== nextState.isSourceAllowed ||
+      this.state.allowedSources !== nextState.allowedSources
+    ) {
       return true;
     }
 
@@ -126,8 +145,18 @@ class CreatingStepInitialize extends ProgressStep<Props, State> {
 
     // skip source validation for devworkspace resources (samples)
     if (useDevWorkspaceResources === false) {
+      const isSourceAllowed = this.isSourceAllowed(sourceUrl);
+      if (isSourceAllowed === false) {
+        throw new Error(
+          `The specified source URL "${sourceUrl}" is not permitted for creating a workspace. Please contact your system administrator.`,
+        );
+      }
+
       // check if the source is trusted
-      const isSourceTrusted = this.isSourceTrusted(sourceUrl);
+      const isSourceTrusted =
+        this.isSourceTrusted(this.props.trustedSources, sourceUrl) ||
+        this.props.allowedSources.length > 0;
+
       if (isSourceTrusted === true) {
         this.setState({
           isSourceTrusted,
@@ -149,6 +178,8 @@ class CreatingStepInitialize extends ProgressStep<Props, State> {
       throw new Error(
         'Could not resolve devfile from private repository because authentication request is missing a parameter, contains an invalid parameter, includes a parameter more than once, or is otherwise invalid.',
       );
+    } else if (errorCode === 'ssl_exception') {
+      throw new Error('SSL handshake failed. Please, contact the cluster administrator.');
     }
 
     // validate creation policies
@@ -237,8 +268,11 @@ class CreatingStepInitialize extends ProgressStep<Props, State> {
     }
   }
 
-  private isSourceTrusted(sourceUrl: string): boolean {
-    const isTrustedSource = this.props.isTrustedSource(sourceUrl);
+  private isSourceTrusted(
+    trustedSources: api.TrustedSources | undefined,
+    sourceUrl: string,
+  ): boolean {
+    const isTrustedSource = isTrustedRepo(trustedSources, sourceUrl);
     const isRegistryDevfile = this.props.isRegistryDevfile(sourceUrl);
     if (isRegistryDevfile || isTrustedSource) {
       return true;
@@ -246,6 +280,12 @@ class CreatingStepInitialize extends ProgressStep<Props, State> {
     return false;
   }
 
+  private isSourceAllowed(sourceUrl: string): boolean {
+    const isRegistryDevfile = this.props.isRegistryDevfile(sourceUrl);
+    const isAllowed = isSourceAllowed(this.props.allowedSources, sourceUrl);
+
+    return isRegistryDevfile || isAllowed;
+  }
   render(): React.ReactElement {
     const { distance, hasChildren } = this.props;
     const { name, lastError } = this.state;
@@ -289,7 +329,8 @@ const mapStateToProps = (state: AppState) => ({
   allWorkspacesLimit: selectAllWorkspacesLimit(state),
   infrastructureNamespaces: selectInfrastructureNamespaces(state),
   isRegistryDevfile: selectIsRegistryDevfile(state),
-  isTrustedSource: selectPreferencesIsTrustedSource(state),
+  trustedSources: selectPreferencesTrustedSources(state),
+  allowedSources: selectAllowedSources(state),
   sshKeys: selectSshKeys(state),
 });
 
