@@ -11,7 +11,7 @@
  */
 
 import { screen, waitFor } from '@testing-library/react';
-import userEvent from '@testing-library/user-event';
+import userEvent, { UserEvent } from '@testing-library/user-event';
 import { createMemoryHistory } from 'history';
 import React from 'react';
 import { Provider } from 'react-redux';
@@ -44,8 +44,12 @@ const matchParams: WorkspaceParams = {
 };
 
 describe('Starting steps, initializing', () => {
+  let user: UserEvent;
+
   beforeEach(() => {
     jest.useFakeTimers();
+
+    user = userEvent.setup({ advanceTimers: jest.advanceTimersByTime });
   });
 
   afterEach(() => {
@@ -391,7 +395,7 @@ describe('Starting steps, initializing', () => {
       const timeoutButton = screen.getByRole('button', {
         name: 'onTimeout',
       });
-      userEvent.click(timeoutButton);
+      await user.click(timeoutButton);
 
       const expectAlertItem = expect.objectContaining({
         title: 'Failed to open the workspace',
@@ -428,13 +432,12 @@ describe('Starting steps, initializing', () => {
       });
 
       renderComponent(store);
-      jest.runAllTimers();
 
       // trigger timeout
       const timeoutButton = screen.getByRole('button', {
         name: 'onTimeout',
       });
-      userEvent.click(timeoutButton);
+      await user.click(timeoutButton);
 
       await waitFor(() => expect(mockOnError).toHaveBeenCalled());
       mockOnError.mockClear();
