@@ -12,7 +12,7 @@
 
 import { api } from '@eclipse-che/common';
 import { screen, waitFor } from '@testing-library/react';
-import userEvent from '@testing-library/user-event';
+import userEvent, { UserEvent } from '@testing-library/user-event';
 import { createMemoryHistory } from 'history';
 import React from 'react';
 import { Provider } from 'react-redux';
@@ -86,11 +86,16 @@ const serverConfig: api.IServerConfig = {
   },
   pluginRegistryURL: '',
   pluginRegistryInternalURL: '',
+  allowedSourceUrls: [],
 };
 
 describe('Starting steps, starting a workspace', () => {
+  let user: UserEvent;
+
   beforeEach(() => {
     jest.useFakeTimers();
+
+    user = userEvent.setup({ advanceTimers: jest.advanceTimersByTime });
   });
 
   afterEach(() => {
@@ -174,15 +179,15 @@ describe('Starting steps, starting a workspace', () => {
       expect(mockOnRestart).not.toHaveBeenCalled();
 
       /* test the action */
+      deferred.resolve();
 
       // resolve deferred to trigger the callback
-      deferred.resolve();
       await jest.runOnlyPendingTimersAsync();
 
       // this mock is called from the action callback above
       await waitFor(() => expect(mockOnRestart).toHaveBeenCalled());
       expect(mockOnNextStep).not.toHaveBeenCalled();
-      expect(mockOnError).toHaveBeenCalled();
+      expect(mockOnError).not.toHaveBeenCalled();
     });
   });
 
@@ -621,7 +626,7 @@ describe('Starting steps, starting a workspace', () => {
       const timeoutButton = screen.getByRole('button', {
         name: 'onTimeout',
       });
-      userEvent.click(timeoutButton);
+      await user.click(timeoutButton);
 
       const expectAlertItem = expect.objectContaining({
         title: 'Failed to open the workspace',
@@ -668,7 +673,7 @@ describe('Starting steps, starting a workspace', () => {
       const timeoutButton = screen.getByRole('button', {
         name: 'onTimeout',
       });
-      userEvent.click(timeoutButton);
+      await user.click(timeoutButton);
 
       await waitFor(() => expect(mockOnError).toHaveBeenCalled());
       mockOnError.mockClear();
