@@ -21,6 +21,7 @@ import {
   ProgressStepState,
 } from '@/components/WorkspaceProgress/ProgressStep';
 import styles from '@/components/WorkspaceProgress/StartingSteps/WorkspaceConditions/index.module.css';
+import { PureSubCondition } from '@/components/WorkspaceProgress/StartingSteps/WorkspaceConditions/PureSubCondition';
 import { ProgressStepTitle } from '@/components/WorkspaceProgress/StepTitle';
 import {
   ConditionType,
@@ -38,9 +39,12 @@ export type State = ProgressStepState & {
   isWarning: boolean;
   isReady: boolean;
   condition: ConditionType;
+  subConditionTitle: string;
 };
 
 export default class StartingStepWorkspaceConditions extends ProgressStep<Props, State> {
+  private timerId: number | undefined;
+
   constructor(props: Props) {
     super(props);
 
@@ -56,10 +60,13 @@ export default class StartingStepWorkspaceConditions extends ProgressStep<Props,
     const prevCondition = prevProps?.condition;
 
     let name: string;
+    let subConditionTitle: string;
     if (state === undefined) {
       name = condition.message || condition.type;
+      subConditionTitle = '';
     } else {
       name = condition.message || state.name;
+      subConditionTitle = state.subConditionTitle;
     }
 
     return {
@@ -67,25 +74,52 @@ export default class StartingStepWorkspaceConditions extends ProgressStep<Props,
       isWarning: isConditionError(condition, prevCondition),
       name,
       condition,
+      subConditionTitle,
     };
   }
 
+  private checkForSubCondition(condition: ConditionType): void {
+    if (this.timerId !== undefined || condition.status !== 'False') {
+      return;
+    }
+
+    // Show sub-condition only for DeploymentReady
+    if (condition.type === 'DeploymentReady') {
+      // Show sub-condition after 20 seconds
+      this.timerId = window.setTimeout(() => {
+        this.setState({
+          subConditionTitle: 'Downloading IDE binaries... (it can take a few minutes)',
+        });
+      }, 20000);
+    }
+  }
+
   public componentDidMount() {
     const state = this.buildState(this.props, undefined, this.state);
     this.setState(state);
+
+    this.checkForSubCondition(state.condition);
   }
 
   public async componentDidUpdate(prevProps: Props) {
     const state = this.buildState(this.props, prevProps, this.state);
     this.setState(state);
+
+    if (state.subConditionTitle === '') {
+      this.checkForSubCondition(state.condition);
+    }
   }
 
   public shouldComponentUpdate(nextProps: Props, nextState: State): boolean {
-    if (isEqual(this.props.condition, nextProps.condition) === false) {
+    if (!isEqual(this.props.condition, nextProps.condition)) {
       return true;
     }
 
-    if (isEqual(this.state.condition, nextState.condition) === false) {
+    if (!isEqual(this.state.condition, nextState.condition)) {
+      return true;
+    }
+
+    if (this.state.subConditionTitle !== nextState.subConditionTitle) {
       return true;
     }
 
@@ -123,8 +157,8 @@ export default class StartingStepWorkspaceConditions extends ProgressStep<Props,
   }
 
   render() {
-    const { hasChildren } = this.props;
-    const { isWarning: isWarning, isReady } = this.state;
+    const { isWarning: isWarning, isReady, subConditionTitle } = this.state;
+    const hasChildren = this.props.hasChildren || !!subConditionTitle;
 
     const distance = isReady ? 1 : 0;
     const isError = false;
@@ -139,6 +173,7 @@ export default class StartingStepWorkspaceConditions extends ProgressStep<Props,
           isWarning={isWarning}
         >
           {this.name}
+          <PureSubCondition distance={distance} title={subConditionTitle} />
         </ProgressStepTitle>
       </React.Fragment>
     );
