@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -25,7 +25,7 @@ import { DevWorkspaceBuilder } from '@/store/__mocks__/devWorkspaceBuilder';
 import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
 import { ActionCreators } from '@/store/Workspaces';
 
-jest.mock('../../store/Workspaces/index', () => {
+jest.mock('@/store/Workspaces/index', () => {
   return {
     actionCreators: {
       requestWorkspaces: (): AppThunk<Action, Promise<void>> => async (): Promise<void> => {
@@ -34,7 +34,7 @@ jest.mock('../../store/Workspaces/index', () => {
     } as ActionCreators,
   };
 });
-jest.mock('../../pages/WorkspacesList', () => {
+jest.mock('@/pages/WorkspacesList', () => {
   const FakeWorkspacesList = (props: { workspaces: Workspace[] }): React.ReactElement => {
     const ids = props.workspaces.map(wksp => (
       <span data-testid="workspace" key={wksp.uid}>
@@ -51,7 +51,7 @@ jest.mock('../../pages/WorkspacesList', () => {
   FakeWorkspacesList.displayName = 'WorkspacesList';
   return FakeWorkspacesList;
 });
-jest.mock('../../components/Fallback', () => <div>Fallback Spinner</div>);
+jest.mock('@/components/Fallback', () => <div>Fallback Spinner</div>);
 
 describe('Workspaces List Container', () => {
   afterEach(() => {
