@@ -54,6 +54,7 @@ import * as UserProfileStore from '@/store/User/Profile';
 import * as WorkspacesStore from '@/store/Workspaces';
 import * as DevWorkspacesStore from '@/store/Workspaces/devWorkspaces';
 import { selectDevWorkspacesResourceVersion } from '@/store/Workspaces/devWorkspaces/selectors';
+import { workspacePreferencesActionCreators } from '@/store/Workspaces/Preferences';
 
 /**
  * This class executes initial instructions
@@ -105,6 +106,7 @@ export default class Bootstrap {
       }),
       this.fetchClusterConfig().then(() => this.updateFavicon()),
       this.fetchSshKeys(),
+      this.fetchWorkspacePreferences(),
     ]);
 
     const errors = results
@@ -333,13 +335,13 @@ export default class Bootstrap {
 
     const serverConfig = this.store.getState().dwServerConfig.config;
     const devfileRegistry = serverConfig.devfileRegistry;
-    const internalDevfileRegistryUrl = serverConfig.devfileRegistryURL;
     if (
       devfileRegistry?.disableInternalRegistry !== undefined &&
-      devfileRegistry?.disableInternalRegistry !== true &&
-      internalDevfileRegistryUrl
+      devfileRegistry?.disableInternalRegistry !== true
     ) {
-      await requestRegistriesMetadata(internalDevfileRegistryUrl, false)(
+      const airGapedSampleURL = new URL('/dashboard/api/airgap-sample', window.location.origin)
+        .href;
+      await requestRegistriesMetadata(airGapedSampleURL, false)(
         this.store.dispatch,
         this.store.getState,
         undefined,
@@ -444,4 +446,12 @@ export default class Bootstrap {
     const { requestSshKeys } = SshKeysStore.actionCreators;
     await requestSshKeys()(this.store.dispatch, this.store.getState, undefined);
   }
+
+  private async fetchWorkspacePreferences(): Promise<void> {
+    await workspacePreferencesActionCreators.requestPreferences()(
+      this.store.dispatch,
+      this.store.getState,
+      undefined,
+    );
+  }
 }
