@@ -11,6 +11,7 @@
  */
 
 import common from '@eclipse-che/common';
+import { AxiosResponse } from 'axios';
 import { dump, load } from 'js-yaml';
 import { ThunkDispatch } from 'redux-thunk';
 
@@ -35,7 +36,14 @@ export function getErrorMessage(error: unknown): string {
       return 'Unexpected error type. Please report a bug.';
     }
 
-    errorMessage = `HTTP Error code ${code}. Endpoint which throws an error ${endpoint}. ${errorMessage}`;
+    const errorDetails = `HTTP Error code ${code}. Endpoint which throws an error ${endpoint}.`;
+    console.error(errorDetails);
+
+    if (common.helpers.errors.includesAxiosResponse(error) && error.response.data) {
+      errorMessage = error.response.data;
+    } else {
+      errorMessage = `${errorDetails} ${errorMessage}`;
+    }
   }
 
   if (isUnauthorized(error) || isForbidden(error)) {
@@ -98,8 +106,14 @@ function hasStatus(error: unknown, _status: number): boolean {
       return true;
     }
   } else if (typeof error === 'object' && error !== null) {
-    const { status, statusCode } = error as { [propName: string]: string | number };
-    if (statusCode == _status || status == _status) {
+    const { status, statusCode, response } = error as {
+      [propName: string]: string | number | unknown;
+    };
+    if (
+      statusCode == _status ||
+      status == _status ||
+      (response && (response as AxiosResponse).status == _status)
+    ) {
       return true;
     } else {
       try {
@@ -140,7 +154,7 @@ export async function getCustomEditor(
     console.debug('Using the repository .che/che-editor.yaml file', cheEditorYaml);
 
     let repositoryEditorYaml: devfileApi.Devfile | undefined;
-    let repositoryEditorYamlUrl: string | undefined;
+    let editorReference: string | undefined;
     // it's an inlined editor, use the inline content
     if (cheEditorYaml.inline) {
       console.debug('Using the inline content of the repository editor');
@@ -151,17 +165,17 @@ export async function getCustomEditor(
 
       // registryUrl ?
       if (cheEditorYaml.registryUrl) {
-        repositoryEditorYamlUrl = `${cheEditorYaml.registryUrl}/plugins/${cheEditorYaml.id}/devfile.yaml`;
+        editorReference = `${cheEditorYaml.registryUrl}/plugins/${cheEditorYaml.id}/devfile.yaml`;
       } else {
-        repositoryEditorYamlUrl = `${pluginRegistryUrl}/plugins/${cheEditorYaml.id}/devfile.yaml`;
+        editorReference = cheEditorYaml.id;
       }
     } else if (cheEditorYaml.reference) {
       // load the content of this editor
       console.debug(`Loading editor from reference ${cheEditorYaml.reference}`);
-      repositoryEditorYamlUrl = cheEditorYaml.reference;
+      editorReference = cheEditorYaml.reference;
     }
-    if (repositoryEditorYamlUrl) {
-      const response = await getEditor(repositoryEditorYamlUrl, dispatch, getState);
+    if (editorReference) {
+      const response = await getEditor(editorReference, dispatch, getState);
       if (response.content) {
         const yaml = load(response.content);
         repositoryEditorYaml = isDevfileV2(yaml) ? yaml : undefined;
