@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -20,9 +20,9 @@ const selectState = (state: AppState) => state.gitConfig;
 
 export const selectGitConfigIsLoading = createSelector(selectState, state => state.isLoading);
 
-export const selectGitConfigUser = createSelector(
+export const selectGitConfig = createSelector(
   selectState,
-  (state: State) => state.config?.gitconfig.user,
+  (state: State) => state.config?.gitconfig,
 );
 
 export const selectGitConfigError = createSelector(selectState, state => state.error);
