@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,11 +10,12 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import * as cheApi from '@eclipse-che/api';
 import { api } from '@eclipse-che/common';
 
+import { che } from '@/services/models';
+
 export interface IGitOauth {
   name: api.GitOauthProvider;
   endpointUrl: string;
-  links?: cheApi.che.core.rest.Link[];
+  links?: che.api.core.rest.Link[];
 }
