@@ -13,7 +13,6 @@
 import { createSelector } from 'reselect';
 
 import { AppState } from '@/store';
-import { isTrustedRepo } from '@/store/Workspaces/Preferences/helpers';
 
 const selectState = (state: AppState) => state.workspacePreferences;
 
@@ -30,20 +29,3 @@ export const selectPreferencesTrustedSources = createSelector(
   selectPreferences,
   state => state['trusted-sources'],
 );
-
-export const selectPreferencesIsTrustedSource = createSelector(
-  selectPreferencesTrustedSources,
-  trustedSources => {
-    return (location: string) => {
-      if (!trustedSources || (Array.isArray(trustedSources) && trustedSources.length === 0)) {
-        // no trusted sources yet
-        return false;
-      } else if (trustedSources === '*') {
-        // all sources are trusted
-        return true;
-      }
-
-      return isTrustedRepo(trustedSources, location);
-    };
-  },
-);
