@@ -12,7 +12,7 @@
 
 /* eslint-disable @typescript-eslint/no-unused-vars */
 
-import { api } from '@eclipse-che/common';
+import common, { api } from '@eclipse-che/common';
 import { V1Status } from '@kubernetes/client-node';
 import { dump } from 'js-yaml';
 import { AnyAction } from 'redux';
@@ -20,6 +20,8 @@ import { MockStoreEnhanced } from 'redux-mock-store';
 import { ThunkDispatch } from 'redux-thunk';
 
 import { container } from '@/inversify.config';
+import { isRunningDevWorkspacesClusterLimitExceeded } from '@/services/backend-client/devWorkspaceClusterApi';
+import * as factoryApi from '@/services/backend-client/factoryApi';
 import { fetchServerConfig } from '@/services/backend-client/serverConfigApi';
 import { WebsocketClient } from '@/services/backend-client/websocketClient';
 import devfileApi from '@/services/devfileApi';
@@ -30,6 +32,7 @@ import { AppState } from '@/store';
 import { DevWorkspaceBuilder } from '@/store/__mocks__/devWorkspaceBuilder';
 import { FakeStoreBuilder } from '@/store/__mocks__/storeBuilder';
 import * as getEditorModule from '@/store/DevfileRegistries/getEditor';
+import * as testDevWorkspaceClusterStore from '@/store/DevWorkspacesCluster';
 import { AUTHORIZED } from '@/store/sanityCheckMiddleware';
 import * as ServerConfigStore from '@/store/ServerConfig';
 import { checkRunningWorkspacesLimit } from '@/store/Workspaces/devWorkspaces/checkRunningWorkspacesLimit';
@@ -41,6 +44,7 @@ jest.mock('@/services/helpers/delay', () => ({
   delay: jest.fn().mockResolvedValue(undefined),
 }));
 jest.mock('../checkRunningWorkspacesLimit.ts');
+jest.mock('@/services/backend-client/devWorkspaceClusterApi');
 
 jest.mock('@/services/backend-client/devworkspaceResourcesApi', () => ({
   fetchResources: () => `
@@ -142,6 +146,8 @@ const mockOnStart = jest.fn();
 const mockUpdate = jest.fn();
 const mockUpdateAnnotation = jest.fn();
 
+const refreshFactoryOauthTokenSpy = jest.spyOn(factoryApi, 'refreshFactoryOauthToken');
+
 describe('DevWorkspace store, actions', () => {
   const devWorkspaceClient = container.get(DevWorkspaceClient);
   let storeBuilder: FakeStoreBuilder;
@@ -401,6 +407,9 @@ describe('DevWorkspace store, actions', () => {
     });
     it('should create REQUEST_DEVWORKSPACE and UPDATE_DEVWORKSPACE when starting DevWorkspace', async () => {
       (checkRunningWorkspacesLimit as jest.Mock).mockImplementation(() => undefined);
+      (isRunningDevWorkspacesClusterLimitExceeded as jest.Mock).mockReturnValue(
+        Promise.resolve(true),
+      );
 
       const store = storeBuilder.withDevWorkspaces({ workspaces: [devWorkspace] }).build();
 
@@ -408,7 +417,19 @@ describe('DevWorkspace store, actions', () => {
 
       const actions = store.getActions();
 
-      const expectedActions: Array<testStore.KnownAction | ServerConfigStore.KnownAction> = [
+      const expectedActions: Array<
+        | testStore.KnownAction
+        | testDevWorkspaceClusterStore.KnownAction
+        | ServerConfigStore.KnownAction
+      > = [
+        {
+          type: testDevWorkspaceClusterStore.Type.REQUEST_DEVWORKSPACES_CLUSTER,
+          check: AUTHORIZED,
+        },
+        {
+          type: testDevWorkspaceClusterStore.Type.RECEIVED_DEVWORKSPACES_CLUSTER,
+          isRunningDevWorkspacesClusterLimitExceeded: true,
+        },
         {
           type: testStore.Type.REQUEST_DEVWORKSPACE,
           check: AUTHORIZED,
@@ -433,6 +454,9 @@ describe('DevWorkspace store, actions', () => {
       (checkRunningWorkspacesLimit as jest.Mock).mockImplementation(() => {
         throw new Error('Limit reached.');
       });
+      (isRunningDevWorkspacesClusterLimitExceeded as jest.Mock).mockReturnValue(
+        Promise.resolve(true),
+      );
 
       const store = storeBuilder.withDevWorkspaces({ workspaces: [devWorkspace] }).build();
 
@@ -444,7 +468,19 @@ describe('DevWorkspace store, actions', () => {
 
       const actions = store.getActions();
 
-      const expectedActions: Array<testStore.KnownAction | ServerConfigStore.KnownAction> = [
+      const expectedActions: Array<
+        | testStore.KnownAction
+        | testDevWorkspaceClusterStore.KnownAction
+        | ServerConfigStore.KnownAction
+      > = [
+        {
+          type: testDevWorkspaceClusterStore.Type.REQUEST_DEVWORKSPACES_CLUSTER,
+          check: AUTHORIZED,
+        },
+        {
+          type: testDevWorkspaceClusterStore.Type.RECEIVED_DEVWORKSPACES_CLUSTER,
+          isRunningDevWorkspacesClusterLimitExceeded: true,
+        },
         {
           type: testStore.Type.REQUEST_DEVWORKSPACE,
           check: AUTHORIZED,
@@ -457,6 +493,61 @@ describe('DevWorkspace store, actions', () => {
 
       expect(actions).toStrictEqual(expectedActions);
     });
+    it('should refresh token', async () => {
+      // given
+      const projects = [
+        {
+          name: 'project',
+          git: {
+            remotes: {
+              origin: 'origin:project',
+            },
+          },
+        },
+      ];
+      const devWorkspace = new DevWorkspaceBuilder().withProjects(projects).build();
+      const store = storeBuilder.withDevWorkspaces({ workspaces: [devWorkspace] }).build();
+      refreshFactoryOauthTokenSpy.mockResolvedValueOnce();
+
+      // when
+      await store.dispatch(testStore.actionCreators.startWorkspace(devWorkspace));
+
+      // then
+      expect(refreshFactoryOauthTokenSpy).toHaveBeenCalledWith('origin:project');
+    });
+
+    it('should dispatch notification on refresh token failure', async () => {
+      // given
+      const projects = [
+        {
+          name: 'project',
+          git: {
+            remotes: {
+              origin: 'origin:project',
+            },
+          },
+        },
+      ];
+      const devWorkspace = new DevWorkspaceBuilder().withProjects(projects).build();
+      const store = storeBuilder.withDevWorkspaces({ workspaces: [devWorkspace] }).build();
+      const error = {
+        response: {
+          data: { attributes: { provider: 'github' }, message: 'test message' },
+        },
+      };
+      jest.spyOn(common.helpers.errors, 'includesAxiosResponse').mockImplementation(() => true);
+      refreshFactoryOauthTokenSpy.mockRejectedValueOnce(error);
+
+      // when
+      await store.dispatch(testStore.actionCreators.startWorkspace(devWorkspace));
+
+      // then
+      const actions = store.getActions();
+      expect(actions[0].type).toBe('UPDATE_WARNING');
+      expect(actions[0].warning).toBe(
+        "GitHub might not be operational, please check the provider's status page.",
+      );
+    });
   });
 
   describe('updateWorkspaceWithDefaultDevfile', () => {
