@@ -12,6 +12,7 @@
 
 import { V1alpha2DevWorkspaceStatus } from '@devfile/api';
 import common, { api, ApplicationId } from '@eclipse-che/common';
+import { includesAxiosResponse } from '@eclipse-che/common/lib/helpers/errors';
 import { dump } from 'js-yaml';
 import { Action, Reducer } from 'redux';
 
@@ -50,6 +51,8 @@ import { AppThunk } from '@/store';
 import { selectApplications } from '@/store/ClusterInfo/selectors';
 import { getEditor } from '@/store/DevfileRegistries/getEditor';
 import { selectDefaultDevfile } from '@/store/DevfileRegistries/selectors';
+import * as DevWorkspacesCluster from '@/store/DevWorkspacesCluster';
+import { checkRunningDevWorkspacesClusterLimitExceeded } from '@/store/DevWorkspacesCluster';
 import { createObject } from '@/store/helpers';
 import { selectDefaultNamespace } from '@/store/InfrastructureNamespaces/selectors';
 import { selectDefaultEditor } from '@/store/Plugins/devWorkspacePlugins/selectors';
@@ -310,11 +313,45 @@ export const actionCreators: ActionCreators = {
       }
       try {
         await OAuthService.refreshTokenIfProjectExists(workspace);
+      } catch (e: unknown) {
+        if (includesAxiosResponse(e)) {
+          // Do not interrupt the workspace start, but show a warning notification.
+          const response = e.response;
+          const attributes = response.data.attributes;
+          let message = response.data.message;
+          let provider = '';
+          if (attributes !== undefined && attributes.provider !== undefined) {
+            const providerAttribute: string = attributes.provider;
+            if (providerAttribute.startsWith('github')) {
+              provider = 'GitHub';
+            } else if (providerAttribute.startsWith('gitlab')) {
+              provider = 'Gitlab';
+            } else if (providerAttribute.startsWith('bitbucket')) {
+              provider = 'Bitbucket';
+            }
+          }
+          if (provider.length > 0) {
+            // eslint-disable-next-line no-warning-comments
+            // TODO add status page url for each provider when https://github.com/eclipse-che/che/issues/23142 is fixed
+            message = `${provider} might not be operational, please check the provider's status page.`;
+          }
+          dispatch({
+            type: Type.UPDATE_WARNING,
+            workspace: workspace,
+            warning: message,
+          });
+        }
+      }
+      try {
+        await dispatch(
+          DevWorkspacesCluster.actionCreators.requestRunningDevWorkspacesClusterLimitExceeded(),
+        );
         await dispatch({ type: Type.REQUEST_DEVWORKSPACE, check: AUTHORIZED });
         if (!(await selectAsyncIsAuthorized(getState()))) {
           const error = selectSanityCheckError(getState());
           throw new Error(error);
         }
+        checkRunningDevWorkspacesClusterLimitExceeded(getState());
         checkRunningWorkspacesLimit(getState());
 
         if (workspace.metadata.annotations?.[DEVWORKSPACE_NEXT_START_ANNOTATION]) {
@@ -384,8 +421,6 @@ export const actionCreators: ActionCreators = {
         const startingTimeout = 10000;
         await Promise.race([defer.promise, delay(startingTimeout)]);
         toDispose.dispose();
-
-        getDevWorkspaceClient().checkForDevWorkspaceError(startingWorkspace);
       } catch (e) {
         // Skip unauthorised errors. The page is redirecting to an SCM authentication page.
         if (common.helpers.errors.includesAxiosResponse(e) && isOAuthResponse(e.response.data)) {
