@@ -84,6 +84,7 @@ export class FakeStoreBuilder {
         },
         pluginRegistryURL: '',
         pluginRegistryInternalURL: '',
+        allowedSourceUrls: [],
       } as api.IServerConfig,
     },
     clusterInfo: {
@@ -124,6 +125,10 @@ export class FakeStoreBuilder {
       startedWorkspaces: {},
       warnings: {},
     },
+    devWorkspacesCluster: {
+      isLoading: false,
+      isRunningDevWorkspacesClusterLimitExceeded: false,
+    },
     branding: {
       isLoading: false,
       data: {},
@@ -332,6 +337,18 @@ export class FakeStoreBuilder {
     return this;
   }
 
+  public withDevWorkspacesCluster(
+    options: { isRunningDevWorkspacesClusterLimitExceeded: boolean },
+    isLoading = false,
+    error?: string,
+  ): FakeStoreBuilder {
+    this.state.devWorkspacesCluster.isRunningDevWorkspacesClusterLimitExceeded =
+      options.isRunningDevWorkspacesClusterLimitExceeded;
+    this.state.devWorkspacesCluster.isLoading = isLoading;
+    this.state.devWorkspacesCluster.error = error;
+    return this;
+  }
+
   public withDevWorkspaces(
     options: {
       workspaces?: devfileApi.DevWorkspace[];
